@@ -110,7 +110,7 @@ function configure_make (desc, packdir, verbose)
     endif
 
     if (exist (fullfile (src, "Makefile"), "file"))
-      [status, output] = shell (sprintf ("%s gmake --jobs %i --directory '%s'",
+      [status, output] = shell (sprintf ("%s /usr/pkg/bin/gmake --jobs %i --directory '%s'",
                                          scenv, jobs, src), verbose);
       if (status != 0)
         disp (output);
